//----------------------------------------------------------------------
// penny.js
// Author: Bob Dondero
//----------------------------------------------------------------------

// Omit handling of server-side errors.

const express = require('express');
const mustacheExpress = require('mustache-express');
const database = require('./database');

//----------------------------------------------------------------------

function getAmPm() {
   let hours = new Date().getHours();
   return (hours < 12) ? 'morning' : 'afternoon';
}

function getCurrentTime() {
   return new Date();
}

//----------------------------------------------------------------------

function parseCookies(req) {
   let cookies = {};
   let cookieHeader = req.headers.cookie;
   if (! cookieHeader)
      return cookies;
   let cookieStrs = cookieHeader.split('; ');
   for (let cookieStr of cookieStrs) {
      let nameValue = cookieStr.split('=');
      let name = nameValue[0];
      let value = nameValue[1];
      cookies[name] = value;
   }
   return cookies;
}

//----------------------------------------------------------------------

function index(req, res) {
   process.stdout.write(req.originalUrl + '\n');

   let replacements = {
      ampm: getAmPm(),
      currentTime: getCurrentTime()
   };
   res.render('index', replacements);
}

//----------------------------------------------------------------------

function searchForm(req, res) {
   process.stdout.write(req.originalUrl + '\n');

   let cookies = parseCookies(req);
   let prevAuthor = cookies.prevAuthor;
   if (! prevAuthor)
      prevAuthor = '(None)';

   let replacements = {
      ampm: getAmPm(),
      currentTime: getCurrentTime(),
      prevAuthor: prevAuthor
   };
   res.render('searchform', replacements);
}

//----------------------------------------------------------------------

function searchResults(req, res) {
   function handleBooks(err, books) {  // Error handling omitted
      res.cookie('prevAuthor', author);
      let replacements = {
         ampm: getAmPm(),
         currentTime: getCurrentTime(),
         author: author,
         books: books
      };
      res.render('searchresults', replacements);
   }

   process.stdout.write(req.originalUrl + '\n');

   let author = req.query.author;
   if (! author)
      author = '';
   author = author.trim();

   if (author === '') {
      res.cookie('prevAuthor', '(None)');
      let replacements = {
         ampm: getAmPm(),
         currentTime: getCurrentTime(),
         author: '(None)',
         books: []
      };
      res.render('searchresults', replacements);
   }
   else
      database.getBooks(author, handleBooks);
}

//----------------------------------------------------------------------

let app = express();
app.engine('html', mustacheExpress());
app.set('view engine', 'html');
app.set('views', '.');

app.get('/', index);
app.get('/index', index);
app.get('/searchform', searchForm);
app.get('/searchresults', searchResults);

module.exports = { app };
